# sssekai
[![Windows Build](https://github.com/mos9527/sssekai/actions/workflows/python-publish.yml/badge.svg)](https://github.com/mos9527/sssekai/blob/main/.github/workflows/python-publish.yml) [![Releases](https://img.shields.io/github/downloads/mos9527/sssekai/total.svg)](https://GitHub.com/mos9527/sssekai/releases/) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) 

Command-line tool (w/Python API support) for Project SEKAI (JP: プロジェクトセカイ カラフルステージ！ feat.初音ミク) game assets.

# Installation
**For Windows Users** : Builds are available [here](https://github.com/mos9527/sssekai/releases)

Or get the latest version from PyPI:
```bash
    pip install sssekai
```
...Or install it from source:
```bash
    pip install git+https://github.com/mos9527/sssekai
```

# Documentation
See the [wiki page!](https://github.com/mos9527/sssekai/wiki)

# See Also
https://github.com/mos9527/sssekai_blender_io

# License
MIT

# References
- https://github.com/K0lb3/UnityPy
- https://mos9527.github.io/tags/project-sekai/